@@ -21,6 +21,15 @@
 using namespace Qt::Literals::StringLiterals;
 using namespace KPublicTransport;
 
+#ifdef Q_OS_LINUX
+void initLocale()
+{
+    qputenv("LANG", "en_US.utf-8");
+}
+
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+#endif
+
 class Motis2ParserTest : public QObject
 {
     Q_OBJECT
@@ -83,25 +92,30 @@ private Q_SLOTS:
     {
         QTest::addColumn<QString>("inFileName");
         QTest::addColumn<QString>("outFileName");
+        QTest::addColumn<bool>("arrival");
 
         QTest::newRow("departure")
             << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-departure.in.json")
-            << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-departure.out.json");
+            << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-departure.out.json")
+            << false;
         QTest::newRow("arrival")
             << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-arrival.in.json")
-            << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-arrival.out.json");
+            << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-arrival.out.json")
+            << true;
         QTest::newRow("arrival-realtime")
             << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-arrival-realtime.in.json")
-            << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-arrival-realtime.out.json");
+            << QStringLiteral(SOURCE_DIR "/data/motis2/stopover-arrival-realtime.out.json")
+            << true;
     }
 
     void testParseStopovers()
     {
         QFETCH(QString, inFileName);
         QFETCH(QString, outFileName);
+        QFETCH(bool, arrival);
 
         Motis2Parser p(u"motis"_s);
-        const auto result = p.parseStopTimes(Test::readFile(inFileName));
+        const auto result = p.parseStopTimes(Test::readFile(inFileName), arrival);
         QVERIFY(!result.empty());
         const auto resultJson = Stopover::toJson(result);
         const auto resultRef = QJsonDocument::fromJson(Test::readFile(outFileName)).array();
@@ -147,6 +161,32 @@ private Q_SLOTS:
         QVERIFY(!resultJson.isEmpty());
         QVERIFY(Test::compareJson(outFileName, resultJson, resultRef));
     }
+
+    void testParseTrip_data()
+    {
+        QTest::addColumn<QString>("inFileName");
+        QTest::addColumn<QString>("outFileName");
+
+        QTest::newRow("limited-entry-exit")
+            << QStringLiteral(SOURCE_DIR "/data/motis2/trip-limited-entry-exit.in.json")
+            << QStringLiteral(SOURCE_DIR "/data/motis2/trip-limited-entry-exit.out.json");
+        QTest::newRow("alerts")
+            << QStringLiteral(SOURCE_DIR "/data/motis2/trip-alerts.in.json")
+            << QStringLiteral(SOURCE_DIR "/data/motis2/trip-alerts.out.json");
+    }
+
+    void testParseTrip()
+    {
+        QFETCH(QString, inFileName);
+        QFETCH(QString, outFileName);
+
+        Motis2Parser p(u"motis"_s);
+        const auto result = p.parseItinerary(QJsonDocument::fromJson(Test::readFile(inFileName)).object());
+        const auto resultJson = Journey::toJson(result);
+        const auto resultRef = QJsonDocument::fromJson(Test::readFile(outFileName)).object();
+        QVERIFY(!resultJson.isEmpty());
+        QVERIFY(Test::compareJson(outFileName, resultJson, resultRef));
+    }
 };
 
 QTEST_GUILESS_MAIN(Motis2ParserTest)
