@@ -8,6 +8,7 @@
 #include "hafasjourneyresponse_p.h"
 #include "logging.h"
 
+#include <datatypes/featureutil_p.h>
 #include <json/jsonp_p.h>
 
 #include <KPublicTransport/Journey>
@@ -24,6 +25,7 @@
 
 #include <zlib.h>
 
+using namespace Qt::Literals;
 using namespace KPublicTransport;
 
 HafasQueryParser::HafasQueryParser() = default;
@@ -312,35 +314,52 @@ std::vector<Journey> HafasQueryParser::parseQueryJourneyResponse(const QByteArra
             if (sectionInfo->type == HafasJourneyResponseSectionMode::PublicTransport) {
                 Route route;
                 Line line;
-                line.setName(stringTable.lookup(sectionInfo->lineNameStr).trimmed());
+                line.setName(stringTable.lookup(sectionInfo->lineNameStr).simplified());
 
                 auto attr = HafasJourneyResponse::attribute(rawData.constData(), extHeader, sectionInfo->sectionAttributeIndex);
                 while (!attr->atEnd()) {
-                    qDebug() << "section attr" << stringTable.lookup(attr->keyStr) << stringTable.lookup(attr->valueStr);
                     const auto key = stringTable.lookup(attr->keyStr);
-                    if (key == QLatin1String("Direction")) {
+                    qDebug() << "section attr" << key << stringTable.lookup(attr->valueStr);
+                    if (key == "Direction"_L1) {
                         const auto dir = stringTable.lookup(attr->valueStr);
-                        if (dir != QLatin1String("---")) {
+                        if (dir != "---"_L1) {
                             route.setDirection(dir.trimmed());
                         }
-                    } else if (key == QLatin1String("Class")) {
+                    } else if (key == "Class"_L1) {
                         line.setMode(parseLineMode(stringTable.lookup(attr->valueStr)));
+                    } else if (key == "Operator"_L1) {
+                        line.setOperatorName(stringTable.lookup(attr->valueStr));
                     }
                     ++attr;
                 }
 
                 const auto *commentPtr = reinterpret_cast<const uint16_t*>(rawData.constBegin() + header->commentTableOffset + sectionInfo->commentIdx);
                 const auto commentCount = *commentPtr;
+                std::vector<Feature> features;
                 for (int i = 0; i < commentCount; ++i) {
                     ++commentPtr;
                     // format: XX - <human readable comment>, where XX is two character code for the comment
                     const auto note = stringTable.lookup(*commentPtr);
                     if (note.size() > 5 && QStringView(note).mid(2, 3) == QLatin1String(" - ")) {
+                        const auto remarkData = HafasParser::lookupRemarkData(u"A", QStringView(note).left(2));
+                        if (remarkData.msg == FeatureRemark) {
+                            Feature f(remarkData.featureType, remarkData.featureAvailability);
+                            f.setName(note.mid(5));
+                            FeatureUtil::add(features, std::move(f));
+                            continue;
+                        }
+                        if (remarkData.msg == IgnoreRemark) {
+                            continue;
+                        }
+                        if (remarkData.msg == UndefinedRemark) {
+                            qDebug() << "unknown vehicle attribute" << note;
+                        }
                         section.addNote(note.mid(5));
                     } else {
                         section.addNote(note);
                     }
                 }
+                section.setFeatures(std::move(features));
 
                 route.setLine(line);
                 section.setRoute(route);
@@ -352,7 +371,7 @@ std::vector<Journey> HafasQueryParser::parseQueryJourneyResponse(const QByteArra
                     + extHeader->detailsOffset
                     + journeyDetailsOffset
                     + detailsHeader->sectionDetailsOffset
-                    + detailsHeader->sectionDetailsSize * sectionIdx);
+                    + (detailsHeader->sectionDetailsSize * sectionIdx));
                 qDebug() << "section detail" << sectionDetail->expectedArrivalPlatformStr <<  sectionDetail->expectedDeparturePlatformStr;
                 section.setExpectedDeparturePlatform(stringTable.lookup(sectionDetail->expectedDeparturePlatformStr));
                 section.setExpectedArrivalPlatform(stringTable.lookup(sectionDetail->expectedArrivalPlatformStr));
@@ -363,12 +382,15 @@ std::vector<Journey> HafasQueryParser::parseQueryJourneyResponse(const QByteArra
                 std::vector<Stopover> stops;
                 stops.reserve(sectionDetail->numStops);
                 for (int i = 0; i < sectionDetail->numStops; ++i) {
-                    const auto stopInfo = reinterpret_cast<const HafasJourneyResponseStop*>(rawData.constData() + extHeader->detailsOffset + detailsHeader->stopsOffset + i * detailsHeader->stopsSize);
+                    const auto stopInfo = reinterpret_cast<const HafasJourneyResponseStop*>(rawData.constData()
+                        + extHeader->detailsOffset
+                        + detailsHeader->stopsOffset
+                        + ((sectionDetail->stopIndex + i) * detailsHeader->stopsSize));
 
                     Location loc;
                     const auto locInfo = reinterpret_cast<const HafasJourneyResponseStation*>(rawData.constData()
                         + header->stationTableOffset
-                        + stopInfo->stationIdx * sizeof(HafasJourneyResponseStation));
+                        + (stopInfo->stationIdx * sizeof(HafasJourneyResponseStation)));
                     loc.setName(stringTable.lookup(locInfo->nameStr));
                     loc.setLatitude(locInfo->latitude / 1000000.0);
                     loc.setLongitude(locInfo->longitude / 1000000.0);
