@@ -370,10 +370,11 @@ bool OpenTripPlannerGraphQLBackend::queryJourney(const JourneyRequest &req, Jour
 
 bool OpenTripPlannerGraphQLBackend::queryTrip(const TripRequest &req, TripReply *reply, QNetworkAccessManager *nam) const
 {
-    const auto tripId = req.journeySection().identifier(backendId());
+    const auto tripId = req.identifier(backendId());
     if (tripId.isEmpty()) {
         return false;
     }
+    const auto dt = req.journeySection().mode() != JourneySection::Invalid ? req.journeySection().scheduledDepartureTime() : req.stopover().scheduledDepartureTime();
 
     auto gqlReq = graphQLRequest();
     if (const auto &f = graphQLPath(u"trip.graphql"_s); !f.isEmpty()) {
@@ -383,7 +384,7 @@ bool OpenTripPlannerGraphQLBackend::queryTrip(const TripRequest &req, TripReply
         return false;
     }
     gqlReq.setVariable(u"id"_s, tripId);
-    gqlReq.setVariable(u"serviceDate"_s, req.journeySection().scheduledDepartureTime().date().toString("yyyyMMdd"_L1));
+    gqlReq.setVariable(u"serviceDate"_s, dt.date().toString("yyyyMMdd"_L1));
     if (isLoggingEnabled()) {
         logRequest(req, gqlReq.networkRequest(), gqlReq.rawData());
     }
@@ -407,7 +408,9 @@ KGraphQLRequest OpenTripPlannerGraphQLBackend::graphQLRequest() const
     for (const auto &header : m_extraHeaders) {
         req.networkRequest().setRawHeader(header.first, header.second);
     }
+    applyUserAgent(req.networkRequest());
     applySslConfiguration(req.networkRequest());
+    req.networkRequest().setRawHeader("Accept-Language", preferredLanguages().join(", "_L1).toUtf8());
     return req;
 }
 
